summaryrefslogtreecommitdiffstats
path: root/ppapi/cpp
diff options
context:
space:
mode:
Diffstat (limited to 'ppapi/cpp')
-rw-r--r--ppapi/cpp/dev/var_array_dev.cc96
-rw-r--r--ppapi/cpp/dev/var_dictionary_dev.cc110
-rw-r--r--ppapi/cpp/extensions/dev/alarms_dev.cc10
-rw-r--r--ppapi/cpp/extensions/dev/socket_dev.cc28
-rw-r--r--ppapi/cpp/extensions/dev/socket_dev.h4
-rw-r--r--ppapi/cpp/extensions/dict_field.h14
-rw-r--r--ppapi/cpp/extensions/ext_output_traits.h4
-rw-r--r--ppapi/cpp/extensions/from_var_converter.h16
-rw-r--r--ppapi/cpp/extensions/to_var_converter.h8
-rw-r--r--ppapi/cpp/var_array.cc96
-rw-r--r--ppapi/cpp/var_array.h (renamed from ppapi/cpp/dev/var_array_dev.h)38
-rw-r--r--ppapi/cpp/var_dictionary.cc111
-rw-r--r--ppapi/cpp/var_dictionary.h (renamed from ppapi/cpp/dev/var_dictionary_dev.h)42
13 files changed, 289 insertions, 288 deletions
diff --git a/ppapi/cpp/dev/var_array_dev.cc b/ppapi/cpp/dev/var_array_dev.cc
deleted file mode 100644
index 247e9c4..0000000
--- a/ppapi/cpp/dev/var_array_dev.cc
+++ /dev/null
@@ -1,96 +0,0 @@
-// Copyright (c) 2013 The Chromium Authors. All rights reserved.
-// Use of this source code is governed by a BSD-style license that can be
-// found in the LICENSE file.
-
-#include "ppapi/cpp/dev/var_array_dev.h"
-
-#include "ppapi/c/dev/ppb_var_array_dev.h"
-#include "ppapi/cpp/logging.h"
-#include "ppapi/cpp/module_impl.h"
-
-namespace pp {
-
-namespace {
-
-template <> const char* interface_name<PPB_VarArray_Dev_0_1>() {
- return PPB_VAR_ARRAY_DEV_INTERFACE_0_1;
-}
-
-} // namespace
-
-VarArray_Dev::VarArray_Dev() : Var(Null()) {
- if (has_interface<PPB_VarArray_Dev_0_1>())
- var_ = get_interface<PPB_VarArray_Dev_0_1>()->Create();
- else
- PP_NOTREACHED();
-}
-
-VarArray_Dev::VarArray_Dev(const Var& var) : Var(var) {
- if (!var.is_array()) {
- PP_NOTREACHED();
-
- // This takes care of releasing the reference that this object holds.
- Var::operator=(Var(Null()));
- }
-}
-
-VarArray_Dev::VarArray_Dev(const PP_Var& var) : Var(var) {
- if (var.type != PP_VARTYPE_ARRAY) {
- PP_NOTREACHED();
-
- // This takes care of releasing the reference that this object holds.
- Var::operator=(Var(Null()));
- }
-}
-
-VarArray_Dev::VarArray_Dev(const VarArray_Dev& other) : Var(other) {
-}
-
-VarArray_Dev::~VarArray_Dev() {
-}
-
-VarArray_Dev& VarArray_Dev::operator=(const VarArray_Dev& other) {
- Var::operator=(other);
- return *this;
-}
-
-Var& VarArray_Dev::operator=(const Var& other) {
- if (other.is_array()) {
- Var::operator=(other);
- } else {
- PP_NOTREACHED();
- Var::operator=(Var(Null()));
- }
- return *this;
-}
-
-Var VarArray_Dev::Get(uint32_t index) const {
- if (!has_interface<PPB_VarArray_Dev_0_1>())
- return Var();
-
- return Var(PASS_REF, get_interface<PPB_VarArray_Dev_0_1>()->Get(var_, index));
-}
-
-PP_Bool VarArray_Dev::Set(uint32_t index, const Var& value) {
- if (!has_interface<PPB_VarArray_Dev_0_1>())
- return PP_FALSE;
-
- return get_interface<PPB_VarArray_Dev_0_1>()->Set(var_, index,
- value.pp_var());
-}
-
-uint32_t VarArray_Dev::GetLength() const {
- if (!has_interface<PPB_VarArray_Dev_0_1>())
- return 0;
-
- return get_interface<PPB_VarArray_Dev_0_1>()->GetLength(var_);
-}
-
-PP_Bool VarArray_Dev::SetLength(uint32_t length) {
- if (!has_interface<PPB_VarArray_Dev_0_1>())
- return PP_FALSE;
-
- return get_interface<PPB_VarArray_Dev_0_1>()->SetLength(var_, length);
-}
-
-} // namespace pp
diff --git a/ppapi/cpp/dev/var_dictionary_dev.cc b/ppapi/cpp/dev/var_dictionary_dev.cc
deleted file mode 100644
index 8fa3f6c..0000000
--- a/ppapi/cpp/dev/var_dictionary_dev.cc
+++ /dev/null
@@ -1,110 +0,0 @@
-// Copyright (c) 2013 The Chromium Authors. All rights reserved.
-// Use of this source code is governed by a BSD-style license that can be
-// found in the LICENSE file.
-
-#include "ppapi/cpp/dev/var_dictionary_dev.h"
-
-#include "ppapi/c/dev/ppb_var_dictionary_dev.h"
-#include "ppapi/cpp/logging.h"
-#include "ppapi/cpp/module_impl.h"
-
-namespace pp {
-
-namespace {
-
-template <> const char* interface_name<PPB_VarDictionary_Dev_0_1>() {
- return PPB_VAR_DICTIONARY_DEV_INTERFACE_0_1;
-}
-
-} // namespace
-
-VarDictionary_Dev::VarDictionary_Dev() : Var(Null()) {
- if (has_interface<PPB_VarDictionary_Dev_0_1>())
- var_ = get_interface<PPB_VarDictionary_Dev_0_1>()->Create();
- else
- PP_NOTREACHED();
-}
-
-VarDictionary_Dev::VarDictionary_Dev(const Var& var) : Var(var) {
- if (!var.is_dictionary()) {
- PP_NOTREACHED();
-
- // This takes care of releasing the reference that this object holds.
- Var::operator=(Var(Null()));
- }
-}
-
-VarDictionary_Dev::VarDictionary_Dev(const PP_Var& var) : Var(var) {
- if (var.type != PP_VARTYPE_DICTIONARY) {
- PP_NOTREACHED();
-
- // This takes care of releasing the reference that this object holds.
- Var::operator=(Var(Null()));
- }
-}
-
-VarDictionary_Dev::VarDictionary_Dev(const VarDictionary_Dev& other)
- : Var(other) {
-}
-
-VarDictionary_Dev::~VarDictionary_Dev() {
-}
-
-VarDictionary_Dev& VarDictionary_Dev::operator=(
- const VarDictionary_Dev& other) {
- Var::operator=(other);
- return *this;
-}
-
-Var& VarDictionary_Dev::operator=(const Var& other) {
- if (other.is_dictionary()) {
- Var::operator=(other);
- } else {
- PP_NOTREACHED();
- Var::operator=(Var(Null()));
- }
- return *this;
-}
-
-Var VarDictionary_Dev::Get(const Var& key) const {
- if (!has_interface<PPB_VarDictionary_Dev_0_1>())
- return Var();
-
- return Var(
- PASS_REF,
- get_interface<PPB_VarDictionary_Dev_0_1>()->Get(var_, key.pp_var()));
-}
-
-PP_Bool VarDictionary_Dev::Set(const Var& key, const Var& value) {
- if (!has_interface<PPB_VarDictionary_Dev_0_1>())
- return PP_FALSE;
-
- return get_interface<PPB_VarDictionary_Dev_0_1>()->Set(var_, key.pp_var(),
- value.pp_var());
-}
-
-void VarDictionary_Dev::Delete(const Var& key) {
- if (has_interface<PPB_VarDictionary_Dev_0_1>())
- get_interface<PPB_VarDictionary_Dev_0_1>()->Delete(var_, key.pp_var());
-}
-
-PP_Bool VarDictionary_Dev::HasKey(const Var& key) const {
- if (!has_interface<PPB_VarDictionary_Dev_0_1>())
- return PP_FALSE;
-
- return get_interface<PPB_VarDictionary_Dev_0_1>()->HasKey(var_, key.pp_var());
-}
-
-VarArray_Dev VarDictionary_Dev::GetKeys() const {
- if (!has_interface<PPB_VarDictionary_Dev_0_1>())
- return VarArray_Dev();
-
- Var result(PASS_REF,
- get_interface<PPB_VarDictionary_Dev_0_1>()->GetKeys(var_));
- if (result.is_array())
- return VarArray_Dev(result);
- else
- return VarArray_Dev();
-}
-
-} // namespace pp
diff --git a/ppapi/cpp/extensions/dev/alarms_dev.cc b/ppapi/cpp/extensions/dev/alarms_dev.cc
index 94baf47..1cf8464 100644
--- a/ppapi/cpp/extensions/dev/alarms_dev.cc
+++ b/ppapi/cpp/extensions/dev/alarms_dev.cc
@@ -5,11 +5,11 @@
#include "ppapi/cpp/extensions/dev/alarms_dev.h"
#include "ppapi/cpp/completion_callback.h"
-#include "ppapi/cpp/dev/var_dictionary_dev.h"
#include "ppapi/cpp/extensions/optional.h"
#include "ppapi/cpp/extensions/to_var_converter.h"
#include "ppapi/cpp/logging.h"
#include "ppapi/cpp/module_impl.h"
+#include "ppapi/cpp/var_dictionary.h"
namespace pp {
@@ -41,7 +41,7 @@ bool Alarm_Dev::Populate(const PP_Ext_Alarms_Alarm_Dev& value) {
if (value.type != PP_VARTYPE_DICTIONARY)
return false;
- VarDictionary_Dev dict(value);
+ VarDictionary dict(value);
bool result = name.Populate(dict);
result = scheduled_time.Populate(dict) && result;
result = period_in_minutes.Populate(dict) && result;
@@ -50,7 +50,7 @@ bool Alarm_Dev::Populate(const PP_Ext_Alarms_Alarm_Dev& value) {
}
Var Alarm_Dev::CreateVar() const {
- VarDictionary_Dev dict;
+ VarDictionary dict;
bool result = name.AddTo(&dict);
result = scheduled_time.AddTo(&dict) && result;
@@ -78,7 +78,7 @@ bool AlarmCreateInfo_Dev::Populate(
if (value.type != PP_VARTYPE_DICTIONARY)
return false;
- VarDictionary_Dev dict(value);
+ VarDictionary dict(value);
bool result = when.Populate(dict);
result = delay_in_minutes.Populate(dict) && result;
result = period_in_minutes.Populate(dict) && result;
@@ -87,7 +87,7 @@ bool AlarmCreateInfo_Dev::Populate(
}
Var AlarmCreateInfo_Dev::CreateVar() const {
- VarDictionary_Dev dict;
+ VarDictionary dict;
bool result = when.MayAddTo(&dict);
result = delay_in_minutes.MayAddTo(&dict) && result;
diff --git a/ppapi/cpp/extensions/dev/socket_dev.cc b/ppapi/cpp/extensions/dev/socket_dev.cc
index 558f01e..a2c9e7f 100644
--- a/ppapi/cpp/extensions/dev/socket_dev.cc
+++ b/ppapi/cpp/extensions/dev/socket_dev.cc
@@ -76,14 +76,14 @@ bool CreateInfo_Dev::Populate(const PP_Ext_Socket_CreateInfo_Dev& value) {
if (value.type != PP_VARTYPE_DICTIONARY)
return false;
- VarDictionary_Dev dict(value);
+ VarDictionary dict(value);
bool result = socket_id.Populate(dict);
return result;
}
Var CreateInfo_Dev::CreateVar() const {
- VarDictionary_Dev dict;
+ VarDictionary dict;
bool result = socket_id.AddTo(&dict);
// Suppress unused variable warnings.
@@ -108,7 +108,7 @@ bool AcceptInfo_Dev::Populate(const PP_Ext_Socket_AcceptInfo_Dev& value) {
if (value.type != PP_VARTYPE_DICTIONARY)
return false;
- VarDictionary_Dev dict(value);
+ VarDictionary dict(value);
bool result = result_code.Populate(dict);
result = socket_id.Populate(dict) && result;
@@ -116,7 +116,7 @@ bool AcceptInfo_Dev::Populate(const PP_Ext_Socket_AcceptInfo_Dev& value) {
}
Var AcceptInfo_Dev::CreateVar() const {
- VarDictionary_Dev dict;
+ VarDictionary dict;
bool result = result_code.AddTo(&dict);
result = socket_id.MayAddTo(&dict) && result;
@@ -140,7 +140,7 @@ bool ReadInfo_Dev::Populate(const PP_Ext_Socket_ReadInfo_Dev& value) {
if (value.type != PP_VARTYPE_DICTIONARY)
return false;
- VarDictionary_Dev dict(value);
+ VarDictionary dict(value);
bool result = result_code.Populate(dict);
result = data.Populate(dict) && result;
@@ -148,7 +148,7 @@ bool ReadInfo_Dev::Populate(const PP_Ext_Socket_ReadInfo_Dev& value) {
}
Var ReadInfo_Dev::CreateVar() const {
- VarDictionary_Dev dict;
+ VarDictionary dict;
bool result = result_code.AddTo(&dict);
result = data.AddTo(&dict) && result;
@@ -170,14 +170,14 @@ bool WriteInfo_Dev::Populate(const PP_Ext_Socket_WriteInfo_Dev& value) {
if (value.type != PP_VARTYPE_DICTIONARY)
return false;
- VarDictionary_Dev dict(value);
+ VarDictionary dict(value);
bool result = bytes_written.Populate(dict);
return result;
}
Var WriteInfo_Dev::CreateVar() const {
- VarDictionary_Dev dict;
+ VarDictionary dict;
bool result = bytes_written.AddTo(&dict);
// Suppress unused variable warnings.
@@ -206,7 +206,7 @@ bool RecvFromInfo_Dev::Populate(const PP_Ext_Socket_RecvFromInfo_Dev& value) {
if (value.type != PP_VARTYPE_DICTIONARY)
return false;
- VarDictionary_Dev dict(value);
+ VarDictionary dict(value);
bool result = result_code.Populate(dict);
result = data.Populate(dict) && result;
result = address.Populate(dict) && result;
@@ -216,7 +216,7 @@ bool RecvFromInfo_Dev::Populate(const PP_Ext_Socket_RecvFromInfo_Dev& value) {
}
Var RecvFromInfo_Dev::CreateVar() const {
- VarDictionary_Dev dict;
+ VarDictionary dict;
bool result = result_code.AddTo(&dict);
result = data.AddTo(&dict) && result;
@@ -250,7 +250,7 @@ bool SocketInfo_Dev::Populate(const PP_Ext_Socket_SocketInfo_Dev& value) {
if (value.type != PP_VARTYPE_DICTIONARY)
return false;
- VarDictionary_Dev dict(value);
+ VarDictionary dict(value);
bool result = socket_type.Populate(dict);
result = connected.Populate(dict) && result;
result = peer_address.Populate(dict) && result;
@@ -262,7 +262,7 @@ bool SocketInfo_Dev::Populate(const PP_Ext_Socket_SocketInfo_Dev& value) {
}
Var SocketInfo_Dev::CreateVar() const {
- VarDictionary_Dev dict;
+ VarDictionary dict;
bool result = socket_type.AddTo(&dict);
result = connected.AddTo(&dict) && result;
@@ -291,7 +291,7 @@ bool NetworkInterface_Dev::Populate(
if (value.type != PP_VARTYPE_DICTIONARY)
return false;
- VarDictionary_Dev dict(value);
+ VarDictionary dict(value);
bool result = name.Populate(dict);
result = address.Populate(dict) && result;
@@ -299,7 +299,7 @@ bool NetworkInterface_Dev::Populate(
}
Var NetworkInterface_Dev::CreateVar() const {
- VarDictionary_Dev dict;
+ VarDictionary dict;
bool result = name.AddTo(&dict);
result = address.AddTo(&dict) && result;
diff --git a/ppapi/cpp/extensions/dev/socket_dev.h b/ppapi/cpp/extensions/dev/socket_dev.h
index 95e78d3..b6ac7b5 100644
--- a/ppapi/cpp/extensions/dev/socket_dev.h
+++ b/ppapi/cpp/extensions/dev/socket_dev.h
@@ -9,12 +9,12 @@
#include <vector>
#include "ppapi/c/extensions/dev/ppb_ext_socket_dev.h"
-#include "ppapi/cpp/dev/var_dictionary_dev.h"
#include "ppapi/cpp/extensions/dict_field.h"
#include "ppapi/cpp/extensions/ext_output_traits.h"
#include "ppapi/cpp/instance_handle.h"
#include "ppapi/cpp/var.h"
#include "ppapi/cpp/var_array_buffer.h"
+#include "ppapi/cpp/var_dictionary.h"
namespace pp {
namespace ext {
@@ -50,7 +50,7 @@ class SocketType_Dev {
static const char* const kUdp;
};
-typedef VarDictionary_Dev CreateOptions_Dev;
+typedef VarDictionary CreateOptions_Dev;
class CreateInfo_Dev {
public:
diff --git a/ppapi/cpp/extensions/dict_field.h b/ppapi/cpp/extensions/dict_field.h
index 5a085c3a..f332014 100644
--- a/ppapi/cpp/extensions/dict_field.h
+++ b/ppapi/cpp/extensions/dict_field.h
@@ -8,11 +8,11 @@
#include <string>
#include "ppapi/c/pp_bool.h"
-#include "ppapi/cpp/dev/var_dictionary_dev.h"
#include "ppapi/cpp/extensions/from_var_converter.h"
#include "ppapi/cpp/extensions/optional.h"
#include "ppapi/cpp/extensions/to_var_converter.h"
#include "ppapi/cpp/var.h"
+#include "ppapi/cpp/var_dictionary.h"
namespace pp {
namespace ext {
@@ -33,15 +33,15 @@ class DictField {
const T& operator()() const { return value_; }
// Adds this field to the dictionary var.
- bool AddTo(VarDictionary_Dev* dict) const {
+ bool AddTo(VarDictionary* dict) const {
if (!dict)
return false;
internal::ToVarConverter<T> converter(value_);
- return PP_ToBool(dict->Set(Var(key_), converter.var()));
+ return dict->Set(Var(key_), converter.var());
}
- bool Populate(const VarDictionary_Dev& dict) {
+ bool Populate(const VarDictionary& dict) {
Var value_var = dict.Get(Var(key_));
if (value_var.is_undefined())
return false;
@@ -72,17 +72,17 @@ class OptionalDictField {
const Optional<T>& operator()() const { return value_; }
// Adds this field to the dictionary var, if |value| has been set.
- bool MayAddTo(VarDictionary_Dev* dict) const {
+ bool MayAddTo(VarDictionary* dict) const {
if (!dict)
return false;
if (!value_.IsSet())
return true;
internal::ToVarConverter<T> converter(*value_);
- return PP_ToBool(dict->Set(Var(key_), converter.var()));
+ return dict->Set(Var(key_), converter.var());
}
- bool Populate(const VarDictionary_Dev& dict) {
+ bool Populate(const VarDictionary& dict) {
Var value_var = dict.Get(Var(key_));
internal::FromVarConverter<Optional<T> > converter(value_var.pp_var());
value_.Swap(&converter.value());
diff --git a/ppapi/cpp/extensions/ext_output_traits.h b/ppapi/cpp/extensions/ext_output_traits.h
index 9c1cb2a..08dc744c 100644
--- a/ppapi/cpp/extensions/ext_output_traits.h
+++ b/ppapi/cpp/extensions/ext_output_traits.h
@@ -8,11 +8,11 @@
#include <vector>
#include "ppapi/c/pp_var.h"
-#include "ppapi/cpp/dev/var_array_dev.h"
#include "ppapi/cpp/extensions/from_var_converter.h"
#include "ppapi/cpp/logging.h"
#include "ppapi/cpp/pass_ref.h"
#include "ppapi/cpp/var.h"
+#include "ppapi/cpp/var_array.h"
namespace pp {
namespace ext {
@@ -92,7 +92,7 @@ class ArrayVarOutputAdapterWithStorage {
Var var(PASS_REF, pp_var_);
pp_var_ = PP_MakeUndefined();
if (var.is_array()) {
- VarArray_Dev array(var);
+ VarArray array(var);
uint32_t length = array.GetLength();
output_storage_.reserve(length);
diff --git a/ppapi/cpp/extensions/from_var_converter.h b/ppapi/cpp/extensions/from_var_converter.h
index 094f0c4..06ae0df 100644
--- a/ppapi/cpp/extensions/from_var_converter.h
+++ b/ppapi/cpp/extensions/from_var_converter.h
@@ -8,12 +8,12 @@
#include <string>
#include "ppapi/c/pp_var.h"
-#include "ppapi/cpp/dev/var_array_dev.h"
-#include "ppapi/cpp/dev/var_dictionary_dev.h"
#include "ppapi/cpp/extensions/optional.h"
#include "ppapi/cpp/logging.h"
#include "ppapi/cpp/var.h"
+#include "ppapi/cpp/var_array.h"
#include "ppapi/cpp/var_array_buffer.h"
+#include "ppapi/cpp/var_dictionary.h"
namespace pp {
namespace ext {
@@ -173,8 +173,8 @@ class FromVarConverter<Var> : public FromVarConverterBase<Var> {
};
template <>
-class FromVarConverter<VarArray_Dev>
- : public FromVarConverterBase<VarArray_Dev> {
+class FromVarConverter<VarArray>
+ : public FromVarConverterBase<VarArray> {
public:
FromVarConverter() {
}
@@ -187,13 +187,13 @@ class FromVarConverter<VarArray_Dev>
}
void Set(const PP_Var& var) {
- FromVarConverterBase<VarArray_Dev>::value_ = Var(var);
+ FromVarConverterBase<VarArray>::value_ = Var(var);
}
};
template <>
-class FromVarConverter<VarDictionary_Dev>
- : public FromVarConverterBase<VarDictionary_Dev> {
+class FromVarConverter<VarDictionary>
+ : public FromVarConverterBase<VarDictionary> {
public:
FromVarConverter() {
}
@@ -206,7 +206,7 @@ class FromVarConverter<VarDictionary_Dev>
}
void Set(const PP_Var& var) {
- FromVarConverterBase<VarDictionary_Dev>::value_ = Var(var);
+ FromVarConverterBase<VarDictionary>::value_ = Var(var);
}
};
diff --git a/ppapi/cpp/extensions/to_var_converter.h b/ppapi/cpp/extensions/to_var_converter.h
index 5913652..e384999 100644
--- a/ppapi/cpp/extensions/to_var_converter.h
+++ b/ppapi/cpp/extensions/to_var_converter.h
@@ -8,11 +8,11 @@
#include <string>
#include "ppapi/c/pp_var.h"
-#include "ppapi/cpp/dev/var_array_dev.h"
-#include "ppapi/cpp/dev/var_dictionary_dev.h"
#include "ppapi/cpp/extensions/optional.h"
#include "ppapi/cpp/var.h"
+#include "ppapi/cpp/var_array.h"
#include "ppapi/cpp/var_array_buffer.h"
+#include "ppapi/cpp/var_dictionary.h"
namespace pp {
namespace ext {
@@ -120,7 +120,7 @@ class ToVarConverter<Var> : public ToVarConverterBase {
};
template <>
-class ToVarConverter<VarArray_Dev> : public ToVarConverterBase {
+class ToVarConverter<VarArray> : public ToVarConverterBase {
public:
explicit ToVarConverter(const Var& object) : ToVarConverterBase(object) {
}
@@ -130,7 +130,7 @@ class ToVarConverter<VarArray_Dev> : public ToVarConverterBase {
};
template <>
-class ToVarConverter<VarDictionary_Dev> : public ToVarConverterBase {
+class ToVarConverter<VarDictionary> : public ToVarConverterBase {
public:
explicit ToVarConverter(const Var& object) : ToVarConverterBase(object) {
}
diff --git a/ppapi/cpp/var_array.cc b/ppapi/cpp/var_array.cc
new file mode 100644
index 0000000..7a504e7
--- /dev/null
+++ b/ppapi/cpp/var_array.cc
@@ -0,0 +1,96 @@
+// Copyright 2013 The Chromium Authors. All rights reserved.
+// Use of this source code is governed by a BSD-style license that can be
+// found in the LICENSE file.
+
+#include "ppapi/cpp/var_array.h"
+
+#include "ppapi/c/ppb_var_array.h"
+#include "ppapi/cpp/logging.h"
+#include "ppapi/cpp/module_impl.h"
+
+namespace pp {
+
+namespace {
+
+template <> const char* interface_name<PPB_VarArray_1_0>() {
+ return PPB_VAR_ARRAY_INTERFACE_1_0;
+}
+
+} // namespace
+
+VarArray::VarArray() : Var(Null()) {
+ if (has_interface<PPB_VarArray_1_0>())
+ var_ = get_interface<PPB_VarArray_1_0>()->Create();
+ else
+ PP_NOTREACHED();
+}
+
+VarArray::VarArray(const Var& var) : Var(var) {
+ if (!var.is_array()) {
+ PP_NOTREACHED();
+
+ // This takes care of releasing the reference that this object holds.
+ Var::operator=(Var(Null()));
+ }
+}
+
+VarArray::VarArray(const PP_Var& var) : Var(var) {
+ if (var.type != PP_VARTYPE_ARRAY) {
+ PP_NOTREACHED();
+
+ // This takes care of releasing the reference that this object holds.
+ Var::operator=(Var(Null()));
+ }
+}
+
+VarArray::VarArray(const VarArray& other) : Var(other) {
+}
+
+VarArray::~VarArray() {
+}
+
+VarArray& VarArray::operator=(const VarArray& other) {
+ Var::operator=(other);
+ return *this;
+}
+
+Var& VarArray::operator=(const Var& other) {
+ if (other.is_array()) {
+ Var::operator=(other);
+ } else {
+ PP_NOTREACHED();
+ Var::operator=(Var(Null()));
+ }
+ return *this;
+}
+
+Var VarArray::Get(uint32_t index) const {
+ if (!has_interface<PPB_VarArray_1_0>())
+ return Var();
+
+ return Var(PASS_REF, get_interface<PPB_VarArray_1_0>()->Get(var_, index));
+}
+
+bool VarArray::Set(uint32_t index, const Var& value) {
+ if (!has_interface<PPB_VarArray_1_0>())
+ return false;
+
+ return PP_ToBool(get_interface<PPB_VarArray_1_0>()->Set(var_, index,
+ value.pp_var()));
+}
+
+uint32_t VarArray::GetLength() const {
+ if (!has_interface<PPB_VarArray_1_0>())
+ return 0;
+
+ return get_interface<PPB_VarArray_1_0>()->GetLength(var_);
+}
+
+bool VarArray::SetLength(uint32_t length) {
+ if (!has_interface<PPB_VarArray_1_0>())
+ return false;
+
+ return PP_ToBool(get_interface<PPB_VarArray_1_0>()->SetLength(var_, length));
+}
+
+} // namespace pp
diff --git a/ppapi/cpp/var_dictionary.cc b/ppapi/cpp/var_dictionary.cc
new file mode 100644
index 0000000..600b1f2
--- /dev/null
+++ b/ppapi/cpp/var_dictionary.cc
@@ -0,0 +1,111 @@
+// Copyright 2013 The Chromium Authors. All rights reserved.
+// Use of this source code is governed by a BSD-style license that can be
+// found in the LICENSE file.
+
+#include "ppapi/cpp/var_dictionary.h"
+
+#include "ppapi/c/ppb_var_dictionary.h"
+#include "ppapi/cpp/logging.h"
+#include "ppapi/cpp/module_impl.h"
+
+namespace pp {
+
+namespace {
+
+template <> const char* interface_name<PPB_VarDictionary_1_0>() {
+ return PPB_VAR_DICTIONARY_INTERFACE_1_0;
+}
+
+} // namespace
+
+VarDictionary::VarDictionary() : Var(Null()) {
+ if (has_interface<PPB_VarDictionary_1_0>())
+ var_ = get_interface<PPB_VarDictionary_1_0>()->Create();
+ else
+ PP_NOTREACHED();
+}
+
+VarDictionary::VarDictionary(const Var& var) : Var(var) {
+ if (!var.is_dictionary()) {
+ PP_NOTREACHED();
+
+ // This takes care of releasing the reference that this object holds.
+ Var::operator=(Var(Null()));
+ }
+}
+
+VarDictionary::VarDictionary(const PP_Var& var) : Var(var) {
+ if (var.type != PP_VARTYPE_DICTIONARY) {
+ PP_NOTREACHED();
+
+ // This takes care of releasing the reference that this object holds.
+ Var::operator=(Var(Null()));
+ }
+}
+
+VarDictionary::VarDictionary(const VarDictionary& other)
+ : Var(other) {
+}
+
+VarDictionary::~VarDictionary() {
+}
+
+VarDictionary& VarDictionary::operator=(
+ const VarDictionary& other) {
+ Var::operator=(other);
+ return *this;
+}
+
+Var& VarDictionary::operator=(const Var& other) {
+ if (other.is_dictionary()) {
+ Var::operator=(other);
+ } else {
+ PP_NOTREACHED();
+ Var::operator=(Var(Null()));
+ }
+ return *this;
+}
+
+Var VarDictionary::Get(const Var& key) const {
+ if (!has_interface<PPB_VarDictionary_1_0>())
+ return Var();
+
+ return Var(
+ PASS_REF,
+ get_interface<PPB_VarDictionary_1_0>()->Get(var_, key.pp_var()));
+}
+
+bool VarDictionary::Set(const Var& key, const Var& value) {
+ if (!has_interface<PPB_VarDictionary_1_0>())
+ return false;
+
+ return PP_ToBool(get_interface<PPB_VarDictionary_1_0>()->Set(
+ var_, key.pp_var(), value.pp_var()));
+}
+
+void VarDictionary::Delete(const Var& key) {
+ if (has_interface<PPB_VarDictionary_1_0>())
+ get_interface<PPB_VarDictionary_1_0>()->Delete(var_, key.pp_var());
+}
+
+bool VarDictionary::HasKey(const Var& key) const {
+ if (!has_interface<PPB_VarDictionary_1_0>())
+ return false;
+
+ return PP_ToBool(get_interface<PPB_VarDictionary_1_0>()->HasKey(
+ var_, key.pp_var()));
+}
+
+VarArray VarDictionary::GetKeys() const {
+ if (!has_interface<PPB_VarDictionary_1_0>())
+ return VarArray();
+
+ Var result(PASS_REF,
+ get_interface<PPB_VarDictionary_1_0>()->GetKeys(var_));
+ if (result.is_array())
+ return VarArray(result);
+ else
+ return VarArray();
+}
+
+} // namespace pp
diff --git a/ppapi/cpp/dev/var_array_dev.h b/ppapi/cpp/var_array.h
index 17a3277..49373ff 100644
--- a/ppapi/cpp/dev/var_array_dev.h
+++ b/ppapi/cpp/var_array.h
@@ -1,9 +1,9 @@
-// Copyright (c) 2013 The Chromium Authors. All rights reserved.
+// Copyright 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef PPAPI_CPP_DEV_VAR_ARRAY_DEV_H_
-#define PPAPI_CPP_DEV_VAR_ARRAY_DEV_H_
+#ifndef PPAPI_CPP_VAR_ARRAY_H_
+#define PPAPI_CPP_VAR_ARRAY_H_
#include "ppapi/c/pp_bool.h"
#include "ppapi/c/pp_stdint.h"
@@ -14,38 +14,38 @@
namespace pp {
-class VarArray_Dev : public Var {
+class VarArray : public Var {
public:
/// Constructs a new array var.
- VarArray_Dev();
+ VarArray();
- /// Constructs a <code>VarArray_Dev</code> given a var for which is_array() is
+ /// Constructs a <code>VarArray</code> given a var for which is_array() is
/// true. This will refer to the same array var, but allow you to access
/// methods specific to arrays.
///
/// @param[in] var An array var.
- explicit VarArray_Dev(const Var& var);
+ explicit VarArray(const Var& var);
- /// Constructs a <code>VarArray_Dev</code> given a <code>PP_Var</code> of type
+ /// Constructs a <code>VarArray</code> given a <code>PP_Var</code> of type
/// PP_VARTYPE_ARRAY.
///
/// @param[in] var A <code>PP_Var</code> of type PP_VARTYPE_ARRAY.
- explicit VarArray_Dev(const PP_Var& var);
+ explicit VarArray(const PP_Var& var);
/// Copy constructor.
- VarArray_Dev(const VarArray_Dev& other);
+ VarArray(const VarArray& other);
- virtual ~VarArray_Dev();
+ virtual ~VarArray();
/// Assignment operator.
- VarArray_Dev& operator=(const VarArray_Dev& other);
+ VarArray& operator=(const VarArray& other);
/// The <code>Var</code> assignment operator is overridden here so that we can
/// check for assigning a non-array var to a <code>VarArray_Dev</code>.
///
/// @param[in] other The array var to be assigned.
///
- /// @return The resulting <code>VarArray_Dev</code> (as a <code>Var</code>&).
+ /// @return The resulting <code>VarArray</code> (as a <code>Var</code>&).
virtual Var& operator=(const Var& other);
/// Gets an element from the array.
@@ -65,8 +65,8 @@ class VarArray_Dev : public Var {
/// type <code>PP_VARTYPE_UNDEFINED</code>.
/// @param[in] value The value to set.
///
- /// @return A <code>PP_Bool</code> indicating whether the operation succeeds.
- PP_Bool Set(uint32_t index, const Var& value);
+ /// @return A <code>bool</code> indicating whether the operation succeeds.
+ bool Set(uint32_t index, const Var& value);
/// Gets the array length.
///
@@ -81,10 +81,10 @@ class VarArray_Dev : public Var {
/// than its current value, undefined vars are appended to increase the array
/// to the specified length.
///
- /// @return A <code>PP_Bool</code> indicating whether the operation succeeds.
- PP_Bool SetLength(uint32_t length);
+ /// @return A <code>bool</code> indicating whether the operation succeeds.
+ bool SetLength(uint32_t length);
};
} // namespace pp
-#endif // PPAPI_CPP_DEV_VAR_ARRAY_DEV_H_
+#endif // PPAPI_CPP_VAR_ARRAY_H_
@@ -14,38 +14,38 @@
/// The <code>Var</code> assignment operator is overridden here so that we can
- /// check for assigning a non-array var to a <code>VarArray_Dev</code>.
+ /// check for assigning a non-array var to a <code>VarArray</code>.
///
/// @param[in] other The array var to be assigned.
diff --git a/ppapi/cpp/dev/var_dictionary_dev.h b/ppapi/cpp/var_dictionary.h
index 2b2e79d..1c5bd2b 100644
--- a/ppapi/cpp/dev/var_dictionary_dev.h
+++ b/ppapi/cpp/var_dictionary.h
@@ -1,52 +1,52 @@
-// Copyright (c) 2013 The Chromium Authors. All rights reserved.
+// Copyright 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef PPAPI_CPP_DEV_VAR_DICTIONARY_DEV_H_
-#define PPAPI_CPP_DEV_VAR_DICTIONARY_DEV_H_
+#ifndef PPAPI_CPP_VAR_DICTIONARY_H_
+#define PPAPI_CPP_VAR_DICTIONARY_H_
#include "ppapi/c/pp_bool.h"
-#include "ppapi/cpp/dev/var_array_dev.h"
#include "ppapi/cpp/var.h"
+#include "ppapi/cpp/var_array.h"
/// @file
/// This file defines the API for interacting with dictionary vars.
namespace pp {
-class VarDictionary_Dev : public Var {
+class VarDictionary : public Var {
public:
/// Constructs a new dictionary var.
- VarDictionary_Dev();
+ VarDictionary();
- /// Constructs a <code>VarDictionary_Dev</code> given a var for which
+ /// Constructs a <code>VarDictionary</code> given a var for which
/// is_dictionary() is true. This will refer to the same dictionary var, but
/// allow you to access methods specific to dictionary.
///
/// @param[in] var A dictionary var.
- explicit VarDictionary_Dev(const Var& var);
+ explicit VarDictionary(const Var& var);
- /// Constructs a <code>VarDictionary_Dev</code> given a <code>PP_Var</code>
+ /// Constructs a <code>VarDictionary</code> given a <code>PP_Var</code>
/// of type PP_VARTYPE_DICTIONARY.
///
/// @param[in] var A <code>PP_Var</code> of type PP_VARTYPE_DICTIONARY.
- explicit VarDictionary_Dev(const PP_Var& var);
+ explicit VarDictionary(const PP_Var& var);
/// Copy constructor.
- VarDictionary_Dev(const VarDictionary_Dev& other);
+ VarDictionary(const VarDictionary& other);
- virtual ~VarDictionary_Dev();
+ virtual ~VarDictionary();
/// Assignment operator.
- VarDictionary_Dev& operator=(const VarDictionary_Dev& other);
+ VarDictionary& operator=(const VarDictionary& other);
/// The <code>Var</code> assignment operator is overridden here so that we can
/// check for assigning a non-dictionary var to a
- /// <code>VarDictionary_Dev</code>.
+ /// <code>VarDictionary</code>.
///
/// @param[in] other The dictionary var to be assigned.
///
- /// @return The resulting <code>VarDictionary_Dev</code> (as a
+ /// @return The resulting <code>VarDictionary</code> (as a
/// <code>Var</code>&).
virtual Var& operator=(const Var& other);
@@ -66,8 +66,8 @@ class VarDictionary_Dev : public Var {
/// previous value is replaced with <code>value</code>.
/// @param[in] value The value to set.
///
- /// @return A <code>PP_Bool</code> indicating whether the operation succeeds.
- PP_Bool Set(const Var& key, const Var& value);
+ /// @return A <code>bool</code> indicating whether the operation succeeds.
+ bool Set(const Var& key, const Var& value);
/// Deletes the specified key and its associated value, if the key exists.
///
@@ -78,16 +78,16 @@ class VarDictionary_Dev : public Var {
///
/// @param[in] key A string var.
///
- /// @return A <code>PP_Bool</code> indicating whether the key exists.
- PP_Bool HasKey(const Var& key) const;
+ /// @return A <code>bool</code> indicating whether the key exists.
+ bool HasKey(const Var& key) const;
/// Gets all the keys in the dictionary.
///
/// @return An array var which contains all the keys of the dictionary.
/// The elements are string vars. Returns an empty array var if failed.
- VarArray_Dev GetKeys() const;
+ VarArray GetKeys() const;
};
} // namespace pp
-#endif // PPAPI_CPP_DEV_VAR_DICTIONARY_DEV_H_
+#endif // PPAPI_CPP_VAR_DICTIONARY_H_